@@ -2,19 +2,19 @@ package images
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"strings"
 
 	"github.com/containers/common/pkg/completion"
 	"github.com/containers/common/pkg/download"
-	"github.com/containers/podman/v4/cmd/podman/registry"
-	"github.com/containers/podman/v4/cmd/podman/validate"
-	"github.com/containers/podman/v4/pkg/domain/entities"
-	"github.com/containers/podman/v4/pkg/util"
-	"github.com/pkg/errors"
+	"github.com/containers/podman/v5/cmd/podman/registry"
+	"github.com/containers/podman/v5/cmd/podman/validate"
+	"github.com/containers/podman/v5/pkg/domain/entities"
+	"github.com/containers/podman/v5/pkg/util"
+	"github.com/containers/storage/pkg/fileutils"
 	"github.com/spf13/cobra"
 	"golang.org/x/term"
 )
@@ -74,7 +74,7 @@ func load(cmd *cobra.Command, args []string) error {
 	if len(loadOpts.Input) > 0 {
 		// Download the input file if needed.
 		if strings.HasPrefix(loadOpts.Input, "https://") || strings.HasPrefix(loadOpts.Input, "http://") {
-			tmpdir, err := util.DefaultContainerConfig().ImageCopyTmpDir()
+			tmpdir, err := registry.PodmanConfig().ContainersConfDefaultsRO.ImageCopyTmpDir()
 			if err != nil {
 				return err
 			}
@@ -86,23 +86,23 @@ func load(cmd *cobra.Command, args []string) error {
 			loadOpts.Input = tmpfile
 		}
 
-		if _, err := os.Stat(loadOpts.Input); err != nil {
+		if err := fileutils.Exists(loadOpts.Input); err != nil {
 			return err
 		}
 	} else {
 		if term.IsTerminal(int(os.Stdin.Fd())) {
-			return errors.Errorf("cannot read from terminal, use command-line redirection or the --input flag")
+			return errors.New("cannot read from terminal, use command-line redirection or the --input flag")
 		}
-		outFile, err := ioutil.TempFile(util.Tmpdir(), "podman")
+		outFile, err := os.CreateTemp(util.Tmpdir(), "podman")
 		if err != nil {
-			return errors.Errorf("creating file %v", err)
+			return fmt.Errorf("creating file %v", err)
 		}
 		defer os.Remove(outFile.Name())
 		defer outFile.Close()
 
 		_, err = io.Copy(outFile, os.Stdin)
 		if err != nil {
-			return errors.Errorf("copying file %v", err)
+			return fmt.Errorf("copying file %v", err)
 		}
 		loadOpts.Input = outFile.Name()
 	}
@@ -110,6 +110,6 @@ func load(cmd *cobra.Command, args []string) error {
 	if err != nil {
 		return err
 	}
-	fmt.Println("Loaded image(s): " + strings.Join(response.Names, ","))
+	fmt.Println("Loaded image: " + strings.Join(response.Names, "\nLoaded image: "))
 	return nil
 }
