@@ -6,16 +6,17 @@ import (
 	"fmt"
 	"os"
 	"sort"
+	"strconv"
 	"strings"
 	"time"
 
 	"github.com/containers/common/pkg/completion"
 	"github.com/containers/common/pkg/report"
-	"github.com/containers/podman/v4/cmd/podman/common"
-	"github.com/containers/podman/v4/cmd/podman/registry"
-	"github.com/containers/podman/v4/cmd/podman/utils"
-	"github.com/containers/podman/v4/cmd/podman/validate"
-	"github.com/containers/podman/v4/pkg/domain/entities"
+	"github.com/containers/podman/v5/cmd/podman/common"
+	"github.com/containers/podman/v5/cmd/podman/registry"
+	"github.com/containers/podman/v5/cmd/podman/utils"
+	"github.com/containers/podman/v5/cmd/podman/validate"
+	"github.com/containers/podman/v5/pkg/domain/entities"
 	"github.com/docker/go-units"
 	"github.com/spf13/cobra"
 )
@@ -52,7 +53,7 @@ func init() {
 	flags.BoolVar(&psInput.CtrStatus, "ctr-status", false, "Display the container status")
 
 	filterFlagName := "filter"
-	flags.StringSliceVarP(&inputFilters, filterFlagName, "f", []string{}, "Filter output based on conditions given")
+	flags.StringArrayVarP(&inputFilters, filterFlagName, "f", []string{}, "Filter output based on conditions given")
 	_ = psCmd.RegisterFlagCompletionFunc(filterFlagName, common.AutocompletePodPsFilters)
 
 	formatFlagName := "format"
@@ -80,11 +81,11 @@ func pods(cmd *cobra.Command, _ []string) error {
 	if cmd.Flag("filter").Changed {
 		psInput.Filters = make(map[string][]string)
 		for _, f := range inputFilters {
-			split := strings.SplitN(f, "=", 2)
-			if len(split) < 2 {
+			fname, filter, hasFilter := strings.Cut(f, "=")
+			if !hasFilter {
 				return fmt.Errorf("filter input must be in the form of filter=value: %s is invalid", f)
 			}
-			psInput.Filters[split[0]] = append(psInput.Filters[split[0]], split[1])
+			psInput.Filters[fname] = append(psInput.Filters[fname], filter)
 		}
 	}
 	responses, err := registry.ContainerEngine().PodPs(context.Background(), psInput)
@@ -147,6 +148,7 @@ func pods(cmd *cobra.Command, _ []string) error {
 			"ContainerStatuses":  "STATUS",
 			"Cgroup":             "CGROUP",
 			"Namespace":          "NAMESPACES",
+			"Restarts":           "RESTARTS",
 		})
 
 		if err := rpt.Execute(headers); err != nil {
@@ -178,6 +180,7 @@ func podPsFormat() string {
 	if !psInput.CtrStatus && !psInput.CtrNames && !psInput.CtrIds {
 		row = append(row, "{{.NumberOfContainers}}")
 	}
+
 	return "{{range . }}" + strings.Join(row, "\t") + "\n" + "{{end -}}"
 }
 
@@ -196,6 +199,11 @@ func (l ListPodReporter) Labels() map[string]string {
 	return l.ListPodsReport.Labels
 }
 
+// Label returns a map of the pod's labels
+func (l ListPodReporter) Label(name string) string {
+	return l.ListPodsReport.Labels[name]
+}
+
 // Networks returns the infra container network names in string format
 func (l ListPodReporter) Networks() string {
 	return strings.Join(l.ListPodsReport.Networks, ",")
@@ -265,6 +273,15 @@ func (l ListPodReporter) ContainerStatuses() string {
 	return strings.Join(statuses, ",")
 }
 
+// Restarts returns the total number of restarts for all the containers in the pod
+func (l ListPodReporter) Restarts() string {
+	restarts := 0
+	for _, c := range l.Containers {
+		restarts += int(c.RestartCount)
+	}
+	return strconv.Itoa(restarts)
+}
+
 func sortPodPsOutput(sortBy string, lprs []*entities.ListPodsReport) error {
 	switch sortBy {
 	case "created":
@@ -278,7 +295,7 @@ func sortPodPsOutput(sortBy string, lprs []*entities.ListPodsReport) error {
 	case "status":
 		sort.Sort(podPsSortedStatus{lprs})
 	default:
-		return errors.New("invalid option for --sort, options are: id, names, or number")
+		return errors.New("invalid option for --sort, options are: created, id, name, number, or status")
 	}
 	return nil
 }
