@@ -21,24 +21,37 @@ source $(dirname $0)/lib.sh
 
 showrun echo "starting"
 
-function _run_validate() {
-    # TODO: aarch64 images need python3-devel installed
-    # https://github.com/containers/automation_images/issues/159
-    showrun bigto ooe.sh dnf install -y python3-devel
+function _run_validate-source() {
+    # This target is only meant to be run on PRs.
+    # We need the following env vars set for the git diff check below.
+    req_env_vars CIRRUS_CHANGE_IN_REPO PR_BASE_SHA
+
+    showrun make validate-source
+
+    # make sure PRs have tests
+    showrun make tests-included
+
+    # make sure PRs have jira links (if needed for branch)
+    showrun make test-jira-links-included
 
-    # git-validation tool fails if $EPOCH_TEST_COMMIT is empty
     # shellcheck disable=SC2154
-    if [[ -n "$EPOCH_TEST_COMMIT" ]]; then
-        showrun make validate
-    else
-        warn "Skipping git-validation since \$EPOCH_TEST_COMMIT is empty"
-    fi
+    head=$CIRRUS_CHANGE_IN_REPO
+    # shellcheck disable=SC2154
+    base=$PR_BASE_SHA
+    echo "_run_validate-source: head=$head  base=$base"
+    diffs=$(git diff --name-only $base $head)
 
+    # If PR touches renovate config validate it, as the image is very big only do so when needed
+    if grep -E -q "^.github/renovate.json5" <<<"$diffs"; then
+        msg "Checking renovate config."
+        showrun podman run \
+            -v ./.github/renovate.json5:/usr/src/app/renovate.json5:z \
+            ghcr.io/renovatebot/renovate:latest \
+            renovate-config-validator
+    fi
 }
 
 function _run_unit() {
-    _bail_if_test_can_be_skipped test/goecho test/version
-
     # shellcheck disable=SC2154
     if [[ "$PODBIN_NAME" != "podman" ]]; then
         # shellcheck disable=SC2154
@@ -48,8 +61,6 @@ function _run_unit() {
 }
 
 function _run_apiv2() {
-    _bail_if_test_can_be_skipped test/apiv2
-
     (
         showrun make localapiv2-bash
         source .venv/requests/bin/activate
@@ -57,39 +68,23 @@ function _run_apiv2() {
     ) |& logformatter
 }
 
-function _run_compose() {
-    _bail_if_test_can_be_skipped test/compose
-
-    showrun ./test/compose/test-compose |& logformatter
-}
-
 function _run_compose_v2() {
-    _bail_if_test_can_be_skipped test/compose
-
     showrun ./test/compose/test-compose |& logformatter
 }
 
 function _run_int() {
-    _bail_if_test_can_be_skipped test/e2e
-
     dotest integration
 }
 
 function _run_sys() {
-    _bail_if_test_can_be_skipped test/system
-
     dotest system
 }
 
 function _run_upgrade_test() {
-    _bail_if_test_can_be_skipped test/system test/upgrade
-
     showrun bats test/upgrade |& logformatter
 }
 
 function _run_bud() {
-    _bail_if_test_can_be_skipped test/buildah-bud
-
     showrun ./test/buildah-bud/run-buildah-bud-tests |& logformatter
 }
 
@@ -97,9 +92,6 @@ function _run_bindings() {
     # install ginkgo
     showrun make .install.ginkgo
 
-    # shellcheck disable=SC2155
-    export PATH=$PATH:$GOSRC/hack:$GOSRC/test/tools/build
-
     # if logformatter sees this, it can link directly to failing source lines
     local gitcommit_magic=
     if [[ -n "$GIT_COMMIT" ]]; then
@@ -120,10 +112,9 @@ function _run_endpoint() {
     showrun make endpoint
 }
 
-function _run_minikube() {
-    _bail_if_test_can_be_skipped test/minikube
-    msg "Testing  minikube."
-    showrun bats test/minikube |& logformatter
+function _run_farm() {
+    msg "Testing podman farm."
+    showrun bats test/farm |& logformatter
 }
 
 exec_container() {
@@ -147,9 +138,11 @@ exec_container() {
 
     # VM Images and Container images are built using (nearly) identical operations.
     set -x
+    env CONTAINERS_REGISTRIES_CONF=/dev/null bin/podman pull -q $CTR_FQIN
     # shellcheck disable=SC2154
     exec bin/podman run --rm --privileged --net=host --cgroupns=host \
-        -v `mktemp -d -p /var/tmp`:/tmp:Z \
+        -v `mktemp -d -p /var/tmp`:/var/tmp:Z \
+        --tmpfs /tmp:mode=1777 \
         -v /dev/fuse:/dev/fuse \
         -v "$GOPATH:$GOPATH:Z" \
         --workdir "$GOSRC" \
@@ -165,9 +158,6 @@ function _run_swagger() {
     local envvarsfile
     req_env_vars GCPJSON GCPNAME GCPPROJECT CTR_FQIN
 
-    [[ -x /usr/local/bin/swagger ]] || \
-        die "Expecting swagger binary to be present and executable."
-
     # The filename and bucket depend on the automation context
     #shellcheck disable=SC2154,SC2153
     if [[ -n "$CIRRUS_PR" ]]; then
@@ -223,7 +213,13 @@ function _run_build() {
     # Ensure always start from clean-slate with all vendor modules downloaded
     showrun make clean
     showrun make vendor
-    showrun make podman-release  # includes podman, podman-remote, and docs
+    showrun make -j $(nproc) --output-sync=target podman-release  # includes podman, podman-remote, and docs
+
+    # There's no reason to validate-binaries across multiple linux platforms
+    # shellcheck disable=SC2154
+    if [[ "$DISTRO_NV" =~ $FEDORA_NAME ]]; then
+        showrun make -j $(nproc) --output-sync=target validate-binaries
+    fi
 
     # Last-minute confirmation that we're testing the desired runtime.
     # This Can't Possibly Fail™ in regular CI; only when updating VMs.
@@ -238,22 +234,21 @@ function _run_build() {
 }
 
 function _run_altbuild() {
-    # Subsequent windows-based tasks require a build.  Var. defined in .cirrus.yml
-    # shellcheck disable=SC2154
-    if [[ ! "$ALT_NAME" =~ Windows ]]; then
-        # We can skip all these steps for test-only PRs, but not doc-only ones
-        _bail_if_test_can_be_skipped docs
-    fi
-
     local -a arches
     local arch
     req_env_vars ALT_NAME
+    # Var. defined in .cirrus.yml
+    # shellcheck disable=SC2154
     msg "Performing alternate build: $ALT_NAME"
     msg "************************************************************"
     set -x
     cd $GOSRC
     case "$ALT_NAME" in
         *Each*)
+            if [[ -z "$CIRRUS_PR" ]]; then
+                echo ".....only meaningful on PRs"
+                return
+            fi
             showrun git fetch origin
             # The make-and-check-size script, introduced 2022-03-22 in #13518,
             # runs 'make' (the original purpose of this check) against
@@ -265,7 +260,8 @@ function _run_altbuild() {
             context_dir=$(mktemp -d --tmpdir make-size-check.XXXXXXX)
             savedhead=$(git rev-parse HEAD)
             # Push to PR base. First run of the script will write size files
-            pr_base=$(git merge-base origin/$DEST_BRANCH HEAD)
+            # shellcheck disable=SC2154
+            pr_base=$PR_BASE_SHA
             showrun git checkout $pr_base
             showrun hack/make-and-check-size $context_dir
             # pop back to PR, and run incremental makes. Subsequent script
@@ -275,22 +271,18 @@ function _run_altbuild() {
             rm -rf $context_dir
             ;;
         *Windows*)
+	    showrun make .install.pre-commit
+            showrun make lint GOOS=windows CGO_ENABLED=0
             showrun make podman-remote-release-windows_amd64.zip
             ;;
         *RPM*)
             showrun make package
             ;;
         Alt*x86*Cross)
-            arches=(\
-                amd64
-                386)
-            _build_altbuild_archs "${arches[@]}"
+            _build_altbuild_archs "386"
             ;;
         Alt*ARM*Cross)
-            arches=(\
-                arm
-                arm64)
-            _build_altbuild_archs "${arches[@]}"
+            _build_altbuild_archs "arm"
             ;;
         Alt*Other*Cross)
             arches=(\
@@ -318,7 +310,7 @@ function _run_altbuild() {
 function _build_altbuild_archs() {
     for arch in "$@"; do
         msg "Building release archive for $arch"
-        showrun make podman-release-${arch}.tar.gz GOARCH=$arch
+        showrun make cross-binaries GOARCH=$arch
     done
 }
 
@@ -360,12 +352,6 @@ function _run_gitlab() {
     return $ret
 }
 
-# TODO: enable fcos_image_build task in cirrus
-#function _run_fcos_image_build() {
-#    # FIXME: Doesn't seem to grab CTXDIR from .cirrus.yml
-#    CTXDIR="contrib/podman-next/fcos-podmanimage"
-#    podman build -t quay.io/podman/fcos:podman-next $CTXDIR
-#}
 
 # Name pattern for logformatter output file, derived from environment
 function output_name() {
@@ -420,66 +406,30 @@ dotest() {
         die "Found fallback podman '$fallback_podman' in \$PATH; tests require none, as a guarantee that we're testing the right binary."
     fi
 
+    # Catch invalid "TMPDIR == /tmp" assumptions; PR #19281
+    TMPDIR=$(mktemp --tmpdir -d CI_XXXX)
+    # tmp dir is commonly 1777 to allow all user to read/write
+    chmod 1777 $TMPDIR
+    export TMPDIR
+    fstype=$(findmnt -n -o FSTYPE --target $TMPDIR)
+    if [[ "$fstype" != "tmpfs" ]]; then
+        die "The CI test TMPDIR is not on a tmpfs mount, we need tmpfs to make the tests faster"
+    fi
+
     showrun make ${localremote}${testsuite} PODMAN_SERVER_LOG=$PODMAN_SERVER_LOG \
         |& logformatter
+
+    # FIXME: https://github.com/containers/podman/issues/22642
+    # Cannot delete this due cleanup errors, as the VM is basically
+    # done after this anyway let's not block on this for now.
+    # rm -rf $TMPDIR
+    # unset TMPDIR
 }
 
-_run_machine() {
-    # N/B: Can't use _bail_if_test_can_be_skipped here b/c content isn't under test/
+_run_machine-linux() {
     showrun make localmachine |& logformatter
 }
 
-# Optimization: will exit if the only PR diffs are under docs/ or tests/
-# with the exception of any given arguments. E.g., don't run e2e or unit
-# or bud tests if the only PR changes are in test/system.
-function _bail_if_test_can_be_skipped() {
-    local head base diffs
-
-    # Cirrus sets these for PRs but not branches or cron. In cron and branches,
-    #we never want to skip.
-    for v in CIRRUS_CHANGE_IN_REPO CIRRUS_PR DEST_BRANCH; do
-        if [[ -z "${!v}" ]]; then
-            msg "[ _cannot do selective skip: \$$v is undefined ]"
-            return 0
-        fi
-    done
-    # And if this one *is* defined, it means we're not in PR-land; don't skip.
-    if [[ -n "$CIRRUS_TAG" ]]; then
-        msg "[ _cannot do selective skip: \$CIRRUS_TAG is defined ]"
-        return 0
-    fi
-
-    # Defined by Cirrus-CI for all tasks
-    # shellcheck disable=SC2154
-    head=$CIRRUS_CHANGE_IN_REPO
-    base=$(git merge-base $DEST_BRANCH $head)
-    diffs=$(git diff --name-only $base $head)
-
-    # If PR touches any files in an argument directory, we cannot skip
-    for subdir in "$@"; do
-        if grep -E -q "^$subdir/" <<<"$diffs"; then
-            return 0
-        fi
-    done
-
-    # PR does not touch any files under our input directories. Now see
-    # if the PR touches files outside of the following directories, by
-    # filtering these out from the diff results.
-    for subdir in docs test; do
-        # || true needed because we're running with set -e
-        diffs=$(grep -E -v "^$subdir/" <<<"$diffs" || true)
-    done
-
-    # If we still have diffs, they indicate files outside of docs & test.
-    # It is not safe to skip.
-    if [[ -n "$diffs" ]]; then
-        return 0
-    fi
-
-    msg "SKIPPING: This is a doc- and/or test-only PR with no changes under $*"
-    exit 0
-}
-
 # Nearly every task in .cirrus.yml makes use of this shell script
 # wrapped by /usr/bin/time to collect runtime statistics.  Because the
 # --output option is used to log stats to a file, every child-process
@@ -506,6 +456,15 @@ msg "************************************************************"
 ((${SETUP_ENVIRONMENT:-0})) || \
     die "Expecting setup_environment.sh to have completed successfully"
 
+if [[ "$UID" -eq 0 ]] && ((CONTAINER==0)); then
+    # start ebpf cleanup tracer (#23487)
+    msg "start ebpf cleanup tracer"
+    # replace zero bytes to make the log more readable
+    bpftrace $GOSRC/hack/podman_cleanup_tracer.bt |& \
+        tr '\0' ' ' >$GOSRC/podman-cleanup-tracer.log &
+    TRACER_PID=$!
+fi
+
 # shellcheck disable=SC2154
 if [[ "$PRIV_NAME" == "rootless" ]] && [[ "$UID" -eq 0 ]]; then
     # Remove /var/lib/cni, it is not required for rootless cni.
@@ -547,4 +506,9 @@ fi
 
 showrun $handler
 
+if [[ -n "$TRACER_PID" ]]; then
+    # ignore any error here
+    kill "$TRACER_PID" || true
+fi
+
 showrun echo "finished"
