@@ -1,3 +1,5 @@
+//go:build !remote
+
 package libpod
 
 import (
@@ -46,6 +48,9 @@ func PodCreate(w http.ResponseWriter, r *http.Request) {
 		infraOptions.Net = &entities.NetOptions{}
 		infraOptions.Devices = psg.Devices
 		infraOptions.SecurityOpt = psg.SecurityOpt
+		if !psg.Userns.IsDefault() {
+			infraOptions.UserNS = psg.Userns.String()
+		}
 		if psg.ShareParent == nil {
 			t := true
 			psg.ShareParent = &t
@@ -68,7 +73,6 @@ func PodCreate(w http.ResponseWriter, r *http.Request) {
 		// a few extra that do not have the same json tags
 		psg.InfraContainerSpec.Name = psg.InfraName
 		psg.InfraContainerSpec.ConmonPidFile = psg.InfraConmonPidFile
-		psg.InfraContainerSpec.ContainerCreateCommand = psg.InfraCommand
 		psg.InfraContainerSpec.Image = psg.InfraImage
 		psg.InfraContainerSpec.RawImageName = psg.InfraImage
 	}
@@ -177,7 +181,10 @@ func PodStop(w http.ResponseWriter, r *http.Request) {
 		}
 	}
 
-	report := entities.PodStopReport{Id: pod.ID()}
+	report := entities.PodStopReport{
+		Id:       pod.ID(),
+		RawInput: pod.Name(),
+	}
 	for id, err := range responses {
 		report.Errs = append(report.Errs, fmt.Errorf("stopping container %s: %w", id, err))
 	}
@@ -199,7 +206,7 @@ func PodStart(w http.ResponseWriter, r *http.Request) {
 	}
 	status, err := pod.GetPodStatus()
 	if err != nil {
-		utils.Error(w, http.StatusInternalServerError, err)
+		utils.InternalServerError(w, err)
 		return
 	}
 	if status == define.PodStateRunning {
@@ -209,11 +216,19 @@ func PodStart(w http.ResponseWriter, r *http.Request) {
 
 	responses, err := pod.Start(r.Context())
 	if err != nil && !errors.Is(err, define.ErrPodPartialFail) {
-		utils.Error(w, http.StatusConflict, err)
+		utils.InternalServerError(w, err)
 		return
 	}
 
-	report := entities.PodStartReport{Id: pod.ID()}
+	cfg, err := pod.Config()
+	if err != nil {
+		utils.InternalServerError(w, err)
+		return
+	}
+	report := entities.PodStartReport{
+		Id:       pod.ID(),
+		RawInput: cfg.Name,
+	}
 	for id, err := range responses {
 		report.Errs = append(report.Errs, fmt.Errorf("%v: %w", "starting container "+id, err))
 	}
@@ -566,14 +581,13 @@ func PodStats(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 
-	var flush = func() {}
+	flush := func() {}
 	if flusher, ok := w.(http.Flusher); ok {
 		flush = flusher.Flush
 	}
 	// Collect the stats and send them over the wire.
 	containerEngine := abi.ContainerEngine{Libpod: runtime}
 	reports, err := containerEngine.PodStats(r.Context(), query.NamesOrIDs, options)
-
 	// Error checks as documented in swagger.
 	if err != nil {
 		if errors.Is(err, define.ErrNoSuchPod) {
